<?php
/**
 * @file
 * Openlayers Solr Layer type.
 */

/**
 * Define the Ctools plugin options.
 */
$plugin = array(
  'title' => t('Apachesolr Layer'),
  'description' => t('Apachesolr integration map layer'),
  'layer_type' => array(
    'file' => 'openlayers_solr.layer.inc',
    'class' => 'openlayers_solr_type',
    'parent' => 'openlayers_layer_type_raw',
  ),
);

class openlayers_solr_type extends openlayers_layer_type_raw {

  /**
   * Provide initial values for options.
   */
  function options_init() {
    return array(
      'layer_type' => 'openlayers_solr_type',
      'layer_handler' => 'openlayers_solr',
      'vector' => TRUE,
      'baselayer' => FALSE,
    );
  }

  /**
   * Options form which generates layers
   */
  function options_form() {
    $environments = apachesolr_load_all_environments();
    $apachesolr_servers = array();
    foreach ($environments as $key => $data) {
      $apachesolr_servers[$key] = $data['name'];
    }

    return array(
      'apache_server' => array(
        '#title' => t('Apachesolr Server'),
        '#type' => 'select',
        '#default_value' => isset($this->data['apache_server']) ? $this->data['apache_server'] : apachesolr_default_environment(),
        '#options' => $apachesolr_servers
      ),
      'layer_type' => array(
        '#type' => 'hidden',
        '#value' => 'openlayers_solr_type'
      ),
    );
  }
  /**
   * Get features for the current search
   *
   * @return
   *   array of features
   */
  function get_features() {
    $results = array();
    $env = apachesolr_default_environment();
    $query = apachesolr_current_query($env);
    if ($query) {
      $searcher = $query->getSearcher();
      $results = apachesolr_static_response_cache($searcher);
    }

    return $this->_get_points($results);
  }

  protected function _get_points($results) {
    $features = array();
    if (!empty($results->response->docs)) {
      foreach ($results->response->docs as $doc) {
        if (!empty($doc->ss_geo_wkt)) {
          $features[] = array(
            'projection' => '4326',
            'wkt' => $doc->ss_geo_wkt,
            'attributes' => array(
              'name' => l($doc->label, $doc->path),
              'description' => $doc->teaser,
            ),
          );
        }
      }
    }

    return $features;
  }

  /**
   * Render.
   */
  function render(&$map) {
    $this->data['features'] = $this->get_features();
    drupal_add_js(drupal_get_path('module', 'openlayers_solr') . '/plugins/layer_types/openlayers_solr.layer.js');
    return $this->options;
  }
}
